@@ -324,6 +324,7 @@ def ParseCreateOptionsBase(
       ),
       enable_legacy_authorization=get_default('enable_legacy_authorization'),
       enable_managed_prometheus=get_default('enable_managed_prometheus'),
+      enable_managed_mldiagnostics=get_default('enable_managed_mldiagnostics'),
       auto_monitoring_scope=get_default('auto_monitoring_scope'),
       enable_master_authorized_networks=get_default(
           'enable_master_authorized_networks'
@@ -347,10 +348,10 @@ def ParseCreateOptionsBase(
       local_ssd_count=get_default('local_ssd_count'),
       maintenance_minor_version_disruption_interval=get_default(
           'maintenance_minor_version_disruption_interval'
-          ),
+      ),
       maintenance_patch_version_disruption_interval=get_default(
           'maintenance_patch_version_disruption_interval'
-          ),
+      ),
       maintenance_window=get_default('maintenance_window'),
       maintenance_window_start=get_default('maintenance_window_start'),
       maintenance_window_end=get_default('maintenance_window_end'),
@@ -516,6 +517,7 @@ def ParseCreateOptionsBase(
           'enable_runtime_vulnerability_insight'
       ),
       workload_policies=get_default('workload_policies'),
+      autopilot_cluster_policies=get_default('autopilot_cluster_policies'),
       in_transit_encryption=get_default('in_transit_encryption'),
       enable_kernel_module_signature_enforcement=get_default(
           'enable_kernel_module_signature_enforcement'
@@ -690,6 +692,9 @@ flags_to_add = {
         'hpaprofile': flags.AddHPAProfilesFlag,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'args': _Args,
         'basicauth': flags.AddBasicAuthFlags,
@@ -874,6 +879,7 @@ flags_to_add = {
         'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
             p, hidden=True
         ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -887,6 +893,9 @@ flags_to_add = {
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'basicauth': flags.AddBasicAuthFlags,
         'binauthz': lambda p: flags.AddBinauthzFlags(
             p, release_track=base.ReleaseTrack.BETA
@@ -1085,6 +1094,9 @@ flags_to_add = {
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
             p, hidden=False
         ),
+        'managedMLDiagnostics': lambda p: flags.AddManagedMLDiagnosticsFlags(
+            p, hidden=True
+        ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
@@ -1111,6 +1123,9 @@ flags_to_add = {
         'autorepair': AddAutoRepair,
         'autoscalingprofiles': flags.AddAutoscalingProfilesFlag,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'hpaprofile': flags.AddHPAProfilesFlag,
         'basicauth': flags.AddBasicAuthFlags,
         'cloudlogging': flags.AddEnableCloudLogging,
@@ -1316,6 +1331,9 @@ flags_to_add = {
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
             p, hidden=False
         ),
+        'managedMLDiagnostics': lambda p: flags.AddManagedMLDiagnosticsFlags(
+            p, hidden=True
+        ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
@@ -1621,6 +1639,9 @@ class CreateBeta(Create):
         get_default('cross_connect_subnetworks'))
     ops.enable_service_externalips = get_default('enable_service_externalips')
     ops.enable_managed_prometheus = get_default('enable_managed_prometheus')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     ops.auto_monitoring_scope = get_default('auto_monitoring_scope')
     ops.spot = get_default('spot')
     ops.maintenance_interval = get_default('maintenance_interval')
@@ -1702,6 +1723,9 @@ class CreateBeta(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     return ops
 
 
@@ -1788,6 +1812,9 @@ class CreateAlpha(Create):
         get_default('cross_connect_subnetworks'))
     ops.enable_service_externalips = get_default('enable_service_externalips')
     ops.enable_managed_prometheus = get_default('enable_managed_prometheus')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     ops.auto_monitoring_scope = get_default('auto_monitoring_scope')
     ops.spot = get_default('spot')
     ops.maintenance_interval = get_default('maintenance_interval')
